function out = xiRD(a, x, y, z)
%characteristic function of a rhombic dodecahedron
%
% edge length is a
% x y and z are arrays produced by meshgrid and are the points at which 
% the characteristic function is to be evaluated.


% four different parallelpipeds make up a rhombic dodecahedron

T1 = inv(a/sqrt(3) .* [1 -1 -1; -1 1 -1; -1 -1 1]);
T2 = inv(a/sqrt(3) .* [1 -1 1; -1 1 1; -1 -1 1]);
T3 = inv(a/sqrt(3) .* [1 -1 1; -1 -1 1; -1 1 1]);
T4 = inv(a/sqrt(3) .* [-1 -1 1; 1 -1 1; -1 1 1]);

p = zeros(3,numel(x));
p(1,:) = reshape(x,1,numel(x));
p(2,:) = reshape(y,1,numel(x));
p(3,:) = reshape(z,1,numel(x));

first = T1*p;
second = T2*p;
third = T3*p;
fourth = T4*p;

out = ...
( first(1,:) >= 0 & first(1,:) <= 1 & ...
first(2,:) >= 0 & first(2,:) <= 1 & ...
first(3,:) >= 0 & first(3,:) <= 1 ) | ...
( second(1,:) >= 0 & second(1,:) <= 1 & ...
second(2,:) >= 0 & second(2,:) <= 1 & ...
second(3,:) >= 0 & second(3,:) <= 1 ) | ...
( third(1,:) >= 0 & third(1,:) <= 1 & ...
third(2,:) >= 0 & third(2,:) <= 1 & ...
third(3,:) >= 0 & third(3,:) <= 1 ) | ...
( fourth(1,:) >= 0 & fourth(1,:) <= 1 & ...
fourth(2,:) >= 0 & fourth(2,:) <= 1 & ...
fourth(3,:) >= 0 & fourth(3,:) <= 1 );

out = reshape(out, size(x));


return