(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    160110,       5296]
NotebookOptionsPosition[    158261,       5232]
NotebookOutlinePosition[    158598,       5247]
CellTagsIndexPosition[    158555,       5244]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Orthogonal Projection Shifted Derivative Filters on the BCC Lattice\
\>", "Title",
 CellChangeTimes->{{3.458058964372697*^9, 3.4580589763254757`*^9}, {
  3.458071822462929*^9, 3.458071822586882*^9}, {3.460473670857172*^9, 
  3.460473673251664*^9}}],

Cell[CellGroupData[{

Cell["Definitions of the Building Block Functions", "Section",
 CellChangeTimes->{{3.458059118047406*^9, 3.45805914297819*^9}, {
  3.46074302407323*^9, 3.460743025032943*^9}}],

Cell[CellGroupData[{

Cell["\<\
Helper functions and definitions of 1D B-splines\
\>", "Subsection",
 CellChangeTimes->{{3.458059023587874*^9, 3.45805904952489*^9}, {
  3.4580591711060534`*^9, 3.4580591752759533`*^9}, {3.478485645549357*^9, 
  3.478485646762841*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"R", "=", 
   RowBox[{
    RowBox[{"1", "/", "2"}], "*", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.443902114154986*^9, 3.4439021834877768`*^9}, {
  3.458058958417066*^9, 3.458058961909067*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Sbs", "[", 
    RowBox[{"n_", ",", "x_"}], "]"}], ":=", 
   RowBox[{"InverseFourierTransform", "[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"1", "-", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "I"}], "*", "w"}], "]"}]}], 
        RowBox[{"I", "*", "w"}]], ")"}], 
      RowBox[{"n", "+", "1"}]], ",", "w", ",", "x", ",", 
     RowBox[{"FourierParameters", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.443902189095229*^9, 3.443902235745463*^9}, {
  3.4439025938716393`*^9, 3.443902635947359*^9}, {3.443902668193769*^9, 
  3.44390272953152*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Box0", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Sbs", "[", 
     RowBox[{"0", ",", "x"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Tent", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Sbs", "[", 
     RowBox[{"1", ",", "x"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Quad", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Sbs", "[", 
     RowBox[{"2", ",", "x"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Cubic", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Sbs", "[", 
     RowBox[{"3", ",", "x"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Quartic", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Sbs", "[", 
     RowBox[{"4", ",", "x"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Tentprime", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Box0", "[", "x", "]"}], "-", 
     RowBox[{"Box0", "[", 
      RowBox[{"x", "-", "1"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Quadprime", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Tent", "[", "x", "]"}], "-", 
     RowBox[{"Tent", "[", 
      RowBox[{"x", "-", "1"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Cubicprime", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Quad", "[", "x", "]"}], "-", 
     RowBox[{"Quad", "[", 
      RowBox[{"x", "-", "1"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Quarticprime", "[", "x_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Cubic", "[", "x", "]"}], "-", 
     RowBox[{"Cubic", "[", 
      RowBox[{"x", "-", "1"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.443902601674026*^9, 3.443902602551865*^9}, {
  3.443902715225357*^9, 3.4439028466284246`*^9}, {3.443902982829195*^9, 
  3.443903016105946*^9}, {3.443903521598184*^9, 3.4439035394022837`*^9}, {
  3.443905449556735*^9, 3.443905504064172*^9}, {3.443905826532113*^9, 
  3.443905879852861*^9}, {3.443905953253234*^9, 3.4439059917211943`*^9}, {
  3.443906045432839*^9, 3.443906055995171*^9}, {3.443906100222641*^9, 
  3.443906112391561*^9}, {3.4439061509902573`*^9, 3.443906153920333*^9}, {
  3.4439062863602*^9, 3.4439063141302843`*^9}, {3.4439072655723677`*^9, 
  3.4439072756800327`*^9}, {3.444073361540482*^9, 3.4440733844820757`*^9}, {
  3.4440875777461357`*^9, 3.4440876079086037`*^9}, {3.4441484106060257`*^9, 
  3.444148453179571*^9}, {3.444149572752542*^9, 3.444149607091098*^9}, {
  3.445191381285131*^9, 3.445191423909698*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Linear, Quintic, Nonic, Tredecic and Septendecic Box Splines", \
"Subsection",
 CellChangeTimes->{{3.444087759883206*^9, 3.4440877691597567`*^9}, {
  3.444148612851123*^9, 3.4441486176491823`*^9}, {3.444149121610832*^9, 
  3.444149124331897*^9}, {3.4441501487655487`*^9, 3.444150150395426*^9}, {
  3.444681077924129*^9, 3.444681104143992*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Lbs", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
   RowBox[{"4", "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       FractionBox["1", "16"], 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"Box0", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "4"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.443902915300997*^9, 3.443902953949894*^9}, {
   3.443903033142562*^9, 3.443903045099889*^9}, {3.4439030789968643`*^9, 
   3.4439031458439503`*^9}, {3.443903228566423*^9, 3.443903229632222*^9}, 
   3.44407039319248*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Qbs", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   RowBox[{"4", "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       FractionBox["1", "16"], 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"Tent", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "8"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.443903702928653*^9, 3.443903738289247*^9}, 
   3.443903860593863*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Nbs", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   RowBox[{"4", "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       FractionBox["1", "16"], 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"Quad", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "12"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.4441501790570498`*^9, 3.444150191261592*^9}, {
  3.444681116074456*^9, 3.444681116433529*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Tdbs", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   RowBox[{"4", "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       FractionBox["1", "16"], 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"Cubic", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "16"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.444073920614644*^9, 3.444073949179372*^9}, {
   3.444681122464025*^9, 3.444681122938513*^9}, 3.44519163024096*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Sdbs", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
   RowBox[{"4", "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{
       FractionBox["1", "16"], 
       RowBox[{"Product", "[", 
        RowBox[{
         RowBox[{"Quartic", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "k", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "4"}], "}"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "20"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.444149237585411*^9, 3.444149248574308*^9}, {
  3.444149279509204*^9, 3.44414928056634*^9}, {3.4446811263324413`*^9, 
  3.4446811275277*^9}, {3.445191632043971*^9, 3.445191638331767*^9}}],

Cell[TextData[{
 "A function that generates BCC points within the bounding box ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"[", 
     RowBox[{
      RowBox[{"-", "n"}], ",", "n"}], "]"}], "3"], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.444072648178198*^9, 3.444072668545528*^9}, {
   3.44407271078839*^9, 3.444072728904887*^9}, {3.444072857382187*^9, 
   3.4440728588739033`*^9}, {3.444072984489847*^9, 3.444072985850934*^9}, 
   3.44407305458512*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BCCpoints", "[", "n_", "]"}], ":=", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Tuples", "[", 
      RowBox[{
       RowBox[{"Range", "[", 
        RowBox[{
         RowBox[{"-", "n"}], ",", "n"}], "]"}], ",", "3"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"EvenQ", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}], "&&", 
         RowBox[{"EvenQ", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "]"}], "&&", 
         RowBox[{"EvenQ", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "]"}]}], " ", ")"}], "||", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"OddQ", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}], "&&", 
         RowBox[{"OddQ", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "]"}], "&&", 
         RowBox[{"OddQ", "[", 
          RowBox[{"#", "[", 
           RowBox[{"[", "3", "]"}], "]"}], "]"}]}], " ", ")"}]}], " ", 
      "&"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.444072688982792*^9, 3.444072701607403*^9}, {
  3.444072861475195*^9, 3.444072874156608*^9}, {3.444073017014442*^9, 
  3.444073017614018*^9}, {3.444073069861034*^9, 3.444073070623472*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Directional Derivative Filters", "Section",
 CellChangeTimes->{{3.458059181672471*^9, 3.4580592212133303`*^9}, {
  3.460740465701106*^9, 3.460740467690815*^9}}],

Cell["\<\
Filters that orthogonally project the directional derivative of a first stage \
approximation. To recover the gradient, we need to compute diectional \
derivatives along the three principle directions of the BCC lattice. \
\>", "Text",
 CellChangeTimes->{{3.458059233294991*^9, 3.4580592594985332`*^9}, {
  3.460740476625784*^9, 3.460740554014366*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Directional Derivatives of a Nonic Box Spline orthogonally projected onto \
shifted Quintic Box Splines (N",
 StyleBox["Qs",
  FontSlant->"Italic"],
 ")"
}], "Subsection",
 CellChangeTimes->{{3.445191892374556*^9, 3.445191955896719*^9}, {
  3.4451919968864594`*^9, 3.4451920169754353`*^9}, {3.458065934924542*^9, 
  3.458065938494625*^9}, {3.46074064943227*^9, 3.460740673969541*^9}, {
  3.478485792764613*^9, 3.4784858060637703`*^9}}],

Cell["\<\
For each directional derivative, we need a different type of shift.
Each can be computed by shifting the directional derivative of a Tredecic Box \
Spline (generated by Cubic B - Splines) \
\>", "Text",
 CellChangeTimes->{{3.445191996709499*^9, 3.44519206409787*^9}, {
  3.460740680246529*^9, 3.4607408049357977`*^9}, {3.4607408803953867`*^9, 
  3.4607408819397707`*^9}, {3.460742073286126*^9, 3.460742076094735*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CdNQ", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_", ",", "i_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["4", "16"], "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Quarticprime", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "j", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         "*", 
         FractionBox["1", "2"], 
         RowBox[{
          RowBox[{"R", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}], "*", 
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{"Quartic", "[", 
            RowBox[{
             FractionBox["1", "2"], "*", 
             RowBox[{
              RowBox[{"R", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ".", 
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
               RowBox[{
                RowBox[{"#", "\[NotEqual]", "j"}], "&"}]}], "]"}]}], "}"}]}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "20"}], "}"}]}], "]"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.44519213011796*^9, 3.445192180473812*^9}, {
  3.478484984248376*^9, 3.47848500427643*^9}, {3.478485821868503*^9, 
  3.4784858230101643`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CdNQ1", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"CdNQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "1"}], "]"}], "-", 
    RowBox[{"CdNQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "2"}], "]"}], "-", 
    RowBox[{"CdNQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "3"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CdNQ2", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"CdNQ", "[", 
      RowBox[{"x", ",", "y", ",", "z", ",", "1"}], "]"}]}], "+", 
    RowBox[{"CdNQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "2"}], "]"}], "-", 
    RowBox[{"CdNQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "3"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CdNQ3", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"CdNQ", "[", 
      RowBox[{"x", ",", "y", ",", "z", ",", "1"}], "]"}]}], "-", 
    RowBox[{"CdNQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "2"}], "]"}], "+", 
    RowBox[{"CdNQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "3"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.460742119373149*^9, 3.460742289006967*^9}, {
  3.478485044010006*^9, 3.47848505067791*^9}, {3.47848524605914*^9, 
  3.478485261710864*^9}}],

Cell["Shifts for the different directions", "Text",
 CellChangeTimes->{{3.460742782146578*^9, 3.4607427907691927`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"shift", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1", ",", 
        RowBox[{"-", "1"}]}], "}"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.460742809759363*^9, 3.4607428613149633`*^9}, 
   3.4607432997626143`*^9, {3.4784851649095497`*^9, 3.47848518088557*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DdNQ1", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#", ",", 
         RowBox[{"CdNQ1", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", " ", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "3"}], "]"}], "]"}]}]}], "]"}]}], "}"}], " ", 
       "&"}], "/@", " ", 
      RowBox[{"BCCpoints", "[", "10", "]"}]}], ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DdNQ2", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#", ",", 
         RowBox[{"CdNQ2", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", " ", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "3"}], "]"}], "]"}]}]}], "]"}]}], "}"}], " ", 
       "&"}], "/@", " ", 
      RowBox[{"BCCpoints", "[", "10", "]"}]}], ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DdNQ3", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#", ",", 
         RowBox[{"CdNQ3", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ",", " ", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"3", ",", "2"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"3", ",", "3"}], "]"}], "]"}]}]}], "]"}]}], "}"}], " ", 
       "&"}], "/@", " ", 
      RowBox[{"BCCpoints", "[", "10", "]"}]}], ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.445192198344434*^9, 3.445192211401208*^9}, {
  3.460742503270327*^9, 3.46074255146975*^9}, {3.4607427315773487`*^9, 
  3.46074273496392*^9}, {3.460742876046555*^9, 3.4607428956775007`*^9}, {
  3.4607429537132263`*^9, 3.46074297740031*^9}, {3.460744170181159*^9, 
  3.4607442208837633`*^9}, {3.4784858593230877`*^9, 3.478485888609963*^9}, {
  3.478491901064837*^9, 3.478491905832224*^9}}],

Cell[CellGroupData[{

Cell["\<\
Directional Derivatives of a Quintic Box Spline orthogonally projected onto a \
shifted Quintic Box Splines (QQs)\
\>", "Subsubsection",
 CellChangeTimes->{{3.48675457674771*^9, 3.486754585063991*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CdQQ", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_", ",", "i_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["4", "16"], "*", 
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cubicprime", "[", 
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{
            RowBox[{"R", "[", 
             RowBox[{"[", "j", "]"}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
         "*", 
         FractionBox["1", "2"], 
         RowBox[{
          RowBox[{"R", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "[", 
          RowBox[{"[", "i", "]"}], "]"}], "*", 
         RowBox[{"Product", "[", 
          RowBox[{
           RowBox[{"Cubic", "[", 
            RowBox[{
             FractionBox["1", "2"], "*", 
             RowBox[{
              RowBox[{"R", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ".", 
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", 
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
               RowBox[{
                RowBox[{"#", "\[NotEqual]", "j"}], "&"}]}], "]"}]}], "}"}]}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"w", ",", "0", ",", "16"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CdQQ1", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"CdQQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "1"}], "]"}], "-", 
    RowBox[{"CdQQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "2"}], "]"}], "-", 
    RowBox[{"CdQQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "3"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CdQQ2", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"CdQQ", "[", 
      RowBox[{"x", ",", "y", ",", "z", ",", "1"}], "]"}]}], "+", 
    RowBox[{"CdQQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "2"}], "]"}], "-", 
    RowBox[{"CdQQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "3"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CdQQ3", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"CdQQ", "[", 
      RowBox[{"x", ",", "y", ",", "z", ",", "1"}], "]"}]}], "-", 
    RowBox[{"CdQQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "2"}], "]"}], "+", 
    RowBox[{"CdQQ", "[", 
     RowBox[{"x", ",", "y", ",", "z", ",", "3"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DdQQ1", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#", ",", 
         RowBox[{"CdQQ1", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", " ", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "3"}], "]"}], "]"}]}]}], "]"}]}], "}"}], " ", 
       "&"}], "/@", " ", 
      RowBox[{"BCCpoints", "[", "8", "]"}]}], ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DdQQ2", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#", ",", 
         RowBox[{"CdQQ2", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "1"}], "]"}], "]"}]}], ",", " ", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "3"}], "]"}], "]"}]}]}], "]"}]}], "}"}], " ", 
       "&"}], "/@", " ", 
      RowBox[{"BCCpoints", "[", "8", "]"}]}], ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DdQQ3", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#", ",", 
         RowBox[{"CdQQ3", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"3", ",", "1"}], "]"}], "]"}]}], ",", " ", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"3", ",", "2"}], "]"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "+", 
            RowBox[{"shift", "[", 
             RowBox[{"[", 
              RowBox[{"3", ",", "3"}], "]"}], "]"}]}]}], "]"}]}], "}"}], " ", 
       "&"}], "/@", " ", 
      RowBox[{"BCCpoints", "[", "8", "]"}]}], ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "\[NotEqual]", "0"}], "&"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.4784918973744183`*^9, 3.4784920385562897`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<DdQQ1.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "DdQQ1"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<DdQQ2.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "DdQQ2"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<DdQQ3.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "DdQQ3"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<DdNQ1.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "DdNQ1"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<DdNQ2.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "DdNQ2"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<DdNQ3.mat\>\"", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], "/@", "DdNQ3"}], ",", 
    "\"\<Mat\>\""}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.4784921361790657`*^9, 3.478492175259531*^9}}],

Cell[CellGroupData[{

Cell[BoxData["DdQQ1"], "Input",
 CellChangeTimes->{{3.478491341691184*^9, 3.478491343360463*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "7"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["25", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1829", "875888640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["1487", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1663", "1362493440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["8221823", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["1007", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19709", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     FractionBox["487", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["11016701", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["6943", "908328960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["31775213", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "4"}], "}"}], ",", 
     FractionBox["21001", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["487", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["6943", "908328960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", "2"}], "}"}], ",", 
     FractionBox["21001", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "4", ",", "4"}], "}"}], ",", 
     FractionBox["1", "1167851520"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["487", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["19709", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19866733", "12262440960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["34402589", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["102820547", "2724986880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["46791673", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "5"}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["19709", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["34402589", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["46791673", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["3451487", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "5"}], "}"}], ",", 
     FractionBox["1007", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "5", ",", "1"}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "5", ",", "3"}], "}"}], ",", 
     FractionBox["1007", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1663", "1362493440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["34402589", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["19866733", "12262440960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["4219589", "222953472"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["1280877911", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "6"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1663", "1362493440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["19866733", "12262440960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["1280877911", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["382327747", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "4"}], "}"}], ",", 
     FractionBox["31775213", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "6"}], "}"}], ",", 
     FractionBox["1487", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "2"}], "}"}], ",", 
     FractionBox["31775213", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "4"}], "}"}], ",", 
     FractionBox["21001", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "6", ",", "0"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "6", ",", "2"}], "}"}], ",", 
     FractionBox["1487", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1829", "875888640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["6943", "908328960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11016701", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1280877911", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["4219589", "222953472"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1829", "875888640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11016701", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["4219589", "222953472"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["139391293", "1167851520"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["102820547", "2724986880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "5"}], "}"}], ",", 
     FractionBox["8221823", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "7"}], "}"}], ",", 
     FractionBox["25", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["102820547", "2724986880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["46791673", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "5"}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", "1"}], "}"}], ",", 
     FractionBox["8221823", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", "3"}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "7", ",", "1"}], "}"}], ",", 
     FractionBox["25", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["25", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["8221823", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["46791673", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["102820547", "2724986880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["25", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["8221823", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["102820547", "2724986880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["139391293", "1167851520"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["4219589", "222953472"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["11016701", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "6"}], "}"}], ",", 
     FractionBox["1829", "875888640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["4219589", "222953472"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["1280877911", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "4"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "6"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["11016701", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", "2"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", "4"}], "}"}], ",", 
     FractionBox["6943", "908328960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "6", ",", "0"}], "}"}], ",", 
     FractionBox["1829", "875888640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "6", ",", "2"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1487", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21001", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["31775213", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1487", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["31775213", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["382327747", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1280877911", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19866733", "12262440960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     FractionBox["1663", "1362493440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1280877911", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["4219589", "222953472"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "5"}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19866733", "12262440960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["34402589", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "5"}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1663", "1362493440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "1"}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "3"}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1007", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1007", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3451487", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["46791673", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["34402589", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19709", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["46791673", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["102820547", "2724986880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["34402589", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["19866733", "12262440960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "4"}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19709", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "2"}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "4"}], "}"}], ",", 
     FractionBox["487", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "1167851520"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21001", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["6943", "908328960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["487", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21001", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["31775213", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["6943", "908328960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11016701", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["487", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["19709", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1007", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["8221823", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1663", "1362493440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1487", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1829", "875888640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["25", "4904976384"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.478491344687295*^9, 3.4784992836793127`*^9, 
  3.4867541280754538`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["DdQQ2"], "Input",
 CellChangeTimes->{{3.486745941431621*^9, 3.4867459437322693`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["25", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1829", "875888640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1487", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1663", "1362493440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["8221823", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1007", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["487", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["19709", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["6943", "908328960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11016701", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21001", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["31775213", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "1167851520"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21001", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["6943", "908328960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["487", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19709", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     FractionBox["487", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["34402589", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["19866733", "12262440960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["46791673", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["102820547", "2724986880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1007", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3451487", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["46791673", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["34402589", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19709", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1007", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1663", "1362493440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", "3"}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19866733", "12262440960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["34402589", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "5"}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1280877911", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["4219589", "222953472"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1487", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["31775213", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["382327747", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1280877911", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19866733", "12262440960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "5"}], "}"}], ",", 
     FractionBox["1663", "1362493440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21001", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["31775213", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1487", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
     FractionBox["1829", "875888640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "6"}], ",", "2"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     FractionBox["11016701", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     FractionBox["6943", "908328960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["4219589", "222953472"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["1280877911", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "6"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["25", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["8221823", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["102820547", "2724986880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["139391293", "1167851520"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["4219589", "222953472"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["11016701", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "6"}], "}"}], ",", 
     FractionBox["1829", "875888640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["46791673", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["102820547", "2724986880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "4"}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["8221823", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "6", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["25", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "7"}], ",", "1"}], "}"}], ",", 
     FractionBox["25", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     FractionBox["8221823", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", "3"}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["102820547", "2724986880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["46791673", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "5"}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1829", "875888640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11016701", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["4219589", "222953472"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["139391293", "1167851520"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["102820547", "2724986880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     FractionBox["8221823", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "7"}], "}"}], ",", 
     FractionBox["25", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1280877911", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["4219589", "222953472"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "5"}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["6943", "908328960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11016701", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1829", "875888640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "6"}], ",", "2"}], "}"}], ",", 
     FractionBox["1487", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     FractionBox["31775213", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     FractionBox["21001", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1663", "1362493440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["19866733", "12262440960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["1280877911", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["382327747", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     FractionBox["31775213", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "6"}], "}"}], ",", 
     FractionBox["1487", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["4219589", "222953472"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["1280877911", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "6"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["34402589", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["19866733", "12262440960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "4"}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1663", "1362493440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "5"}], ",", "3"}], "}"}], ",", 
     FractionBox["1007", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["19709", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["34402589", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["46791673", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["3451487", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "5"}], "}"}], ",", 
     FractionBox["1007", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["102820547", "2724986880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["46791673", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19866733", "12262440960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["34402589", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "5"}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["487", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["19709", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["487", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     FractionBox["6943", "908328960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     FractionBox["21001", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
     FractionBox["1", "1167851520"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["31775213", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     FractionBox["21001", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["11016701", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "4"}], "}"}], ",", 
     FractionBox["6943", "908328960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19709", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "4"}], "}"}], ",", 
     FractionBox["487", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     FractionBox["1007", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["8221823", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["1663", "1362493440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", "3"}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     FractionBox["1487", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1829", "875888640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["25", "4904976384"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.486754128193228*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["DdQQ3"], "Input",
 CellChangeTimes->{{3.486745946537314*^9, 3.4867459498287477`*^9}, {
  3.486754451705989*^9, 3.4867544517958107`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "6"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["25", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1487", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1829", "875888640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1007", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["8221823", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1663", "1362493440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "4"}], ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["487", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["6943", "908328960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21001", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1", "1167851520"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["31775213", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21001", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11016701", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["6943", "908328960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["19709", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "3"}], ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["487", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1007", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19709", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["34402589", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["46791673", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["3451487", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1007", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["102820547", "2724986880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["46791673", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["19866733", "12262440960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["34402589", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "2", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["487", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "4", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19709", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1487", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["31775213", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21001", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["1663", "1362493440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19866733", "12262440960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1280877911", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["382327747", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["31775213", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1487", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["4219589", "222953472"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1280877911", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["34402589", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19866733", "12262440960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5", ",", "1"}], "}"}], ",", 
     FractionBox["1663", "1362493440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "6"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["25", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["8221823", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["102820547", "2724986880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["46791673", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["35267", "8174960640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     FractionBox["1829", "875888640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["11016701", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["4219589", "222953472"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["139391293", "1167851520"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["102820547", "2724986880"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["8221823", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "6"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["25", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1280877911", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["4219589", "222953472"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["6943", "908328960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["11016701", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "4", ",", "2"}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "6", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "6", ",", "0"}], "}"}], ",", 
     FractionBox["1829", "875888640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1829", "875888640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11016701", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["6943", "908328960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["4219589", "222953472"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1280877911", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["81959", "35389440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["2153", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "7"}]}], "}"}], ",", 
     FractionBox["25", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["8221823", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["102820547", "2724986880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["139391293", "1167851520"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["4219589", "222953472"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["11016701", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "5"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1829", "875888640"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["46791673", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["102820547", "2724986880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["8221823", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "1"}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "7", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["25", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1663", "1362493440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "4"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["19866733", "12262440960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["34402589", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", 
       RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["20467", "24524881920"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1280877911", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["4219589", "222953472"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["28959439", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "0", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["264307", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "6"}]}], "}"}], ",", 
     FractionBox["1487", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["31775213", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["382327747", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["1280877911", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["19866733", "12262440960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "4"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["1663", "1362493440"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["21001", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["31775213", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "2"}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "6", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1487", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "6", ",", "0"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["19709", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["487", "4904976384"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["34402589", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19866733", "12262440960"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", 
       RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["294541", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["46791673", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["102820547", "2724986880"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["28959439", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["21773", "4087480320"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "5"}]}], "}"}], ",", 
     FractionBox["1007", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["3451487", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["46791673", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["34402589", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "3", ",", "3"}], "}"}], ",", 
     FractionBox["19709", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "5", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["1007", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "5", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "5", ",", "1"}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["487", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "0"}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"-", 
      FractionBox["19709", "6131220480"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["6943", "908328960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["11016701", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "0", ",", "2"}], "}"}], ",", 
     FractionBox["21773", "4087480320"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["21001", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["31775213", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["81959", "35389440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "2", ",", "2"}], "}"}], ",", 
     FractionBox["294541", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "4", ",", 
       RowBox[{"-", "4"}]}], "}"}], ",", 
     FractionBox["1", "1167851520"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "4", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["21001", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "4", ",", "0"}], "}"}], ",", 
     FractionBox["6943", "908328960"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "4", ",", "2"}], "}"}], ",", 
     FractionBox["487", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     FractionBox["1663", "1362493440"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["8221823", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "1", ",", "1"}], "}"}], ",", 
     FractionBox["264307", "6131220480"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "3", ",", 
       RowBox[{"-", "3"}]}], "}"}], ",", 
     FractionBox["1007", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "3", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["35267", "8174960640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"5", ",", "3", ",", "1"}], "}"}], ",", 
     FractionBox["20467", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "0", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "0", ",", "0"}], "}"}], ",", 
     FractionBox["1829", "875888640"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "2", ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     FractionBox["1487", "24524881920"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "2", ",", "0"}], "}"}], ",", 
     FractionBox["2153", "4904976384"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", "1", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     FractionBox["25", "4904976384"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4867541283104067`*^9, 3.486754453046653*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1280, 755},
WindowMargins->{{3, Automatic}, {Automatic, 21}},
FrontEndVersion->"7.0 for Linux x86 (64-bit) (November 11, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 258, 5, 84, "Title"],
Cell[CellGroupData[{
Cell[850, 31, 175, 2, 72, "Section"],
Cell[CellGroupData[{
Cell[1050, 37, 245, 5, 36, "Subsection"],
Cell[1298, 44, 751, 23, 28, "Input"],
Cell[2052, 69, 774, 22, 56, "Input"],
Cell[2829, 93, 2925, 74, 165, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5791, 172, 349, 5, 36, "Subsection"],
Cell[6143, 179, 1026, 29, 54, "Input"],
Cell[7172, 210, 872, 27, 54, "Input"],
Cell[8047, 239, 898, 27, 54, "Input"],
Cell[8948, 268, 920, 27, 54, "Input"],
Cell[9871, 297, 994, 28, 54, "Input"],
Cell[10868, 327, 478, 12, 33, "Text"],
Cell[11349, 341, 1377, 38, 28, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12775, 385, 166, 2, 72, "Section"],
Cell[12944, 389, 362, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[13331, 399, 453, 10, 37, "Subsection"],
Cell[13787, 411, 427, 7, 51, "Text"],
Cell[14217, 420, 1857, 53, 104, "Input"],
Cell[16077, 475, 1487, 41, 80, "Input"],
Cell[17567, 518, 119, 1, 31, "Text"],
Cell[17689, 521, 760, 24, 54, "Input"],
Cell[18452, 547, 3909, 111, 63, "Input"],
Cell[CellGroupData[{
Cell[22386, 662, 211, 4, 29, "Subsubsection"],
Cell[22600, 668, 6581, 194, 224, "Input"],
Cell[29184, 864, 1461, 43, 114, "Input"],
Cell[CellGroupData[{
Cell[30670, 911, 97, 1, 28, "Input"],
Cell[30770, 914, 42392, 1432, 1529, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73199, 2351, 99, 1, 28, "Input"],
Cell[73301, 2354, 42341, 1431, 1491, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115679, 3790, 150, 2, 28, "Input"],
Cell[115832, 3794, 42365, 1431, 1491, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
